@@ -1,3 +1,5 @@
+from typing import Dict, List
+
 from pydantic.main import BaseModel
 
 
@@ -5,3 +7,4 @@ class ResponseError(BaseModel):
     error_code: int
     description: str
     documentation_link: str
+    additional_info: Dict[str, List[str]]
