@@ -8,14 +8,14 @@ from traveltimepy import TimeFilterFastRequest_pb2
 from traveltimepy.dto.common import Location, Coordinates, FullRange, Property, Range
 from traveltimepy.dto.transportation import PublicTransport, Driving, Ferry, Walking, Cycling, DrivingTrain
 from traveltimepy.dto.requests.time_filter_fast import Transportation
-from traveltimepy.dto.requests.zones import ZonesProperty
+from traveltimepy.dto.requests.postcodes_zones import ZonesProperty
 
 from traveltimepy.dto.requests.postcodes import PostcodesRequest
 from traveltimepy.dto.requests.routes import RoutesRequest
 from traveltimepy.dto.requests.time_filter import TimeFilterRequest
 from traveltimepy.dto.requests.time_filter_fast import TimeFilterFastRequest
 from traveltimepy.dto.requests.time_filter_proto import ProtoTransportation
-from traveltimepy.dto.requests.zones import DistrictsRequest, SectorsRequest
+from traveltimepy.dto.requests.postcodes_zones import PostcodesDistrictsRequest, PostcodesSectorsRequest
 from traveltimepy.dto.requests.time_map import TimeMapRequest
 
 
@@ -23,7 +23,7 @@ from traveltimepy.dto.requests import (
     time_filter,
     time_filter_fast,
     postcodes,
-    zones,
+    postcodes_zones,
     routes,
     time_map
 )
@@ -37,7 +37,7 @@ def create_time_filter(
     departure_time: Optional[datetime],
     arrival_time: Optional[datetime],
     travel_time: int,
-    full_range: Optional[FullRange]
+    range: Optional[FullRange]
 ) -> TimeFilterRequest:
     if properties is None:
         properties = [Property.TRAVEL_TIME]
@@ -56,7 +56,7 @@ def create_time_filter(
                     travel_time=travel_time,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for arrival_id, departure_ids in search_ids.items()
             ],
@@ -74,7 +74,7 @@ def create_time_filter(
                     travel_time=travel_time,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for departure_id, arrival_ids in search_ids.items()
             ],
@@ -141,7 +141,7 @@ def create_postcodes(
     transportation: Union[PublicTransport, Driving, Ferry, Walking, Cycling, DrivingTrain],
     travel_time: int,
     properties: Optional[List[Property]],
-    full_range: Optional[FullRange]
+    range: Optional[FullRange]
 ) -> PostcodesRequest:
     if properties is None:
         properties = [Property.TRAVEL_TIME]
@@ -159,7 +159,7 @@ def create_postcodes(
                     departure_time=departure_time,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for ind, cur_coordinates in enumerate(coordinates)
             ],
@@ -175,7 +175,7 @@ def create_postcodes(
                     arrival_time=arrival_time,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for ind, cur_coordinates in enumerate(coordinates)
             ],
@@ -193,18 +193,18 @@ def create_districts(
     arrival_time: Optional[datetime],
     reachable_postcodes_threshold,
     properties: Optional[List[ZonesProperty]],
-    full_range: Optional[FullRange]
-) -> DistrictsRequest:
+    range: Optional[FullRange]
+) -> PostcodesDistrictsRequest:
     if properties is None:
-        properties = ZonesProperty.TRAVEL_TIME_ALL
+        properties = [ZonesProperty.TRAVEL_TIME_ALL]
 
     if arrival_time is not None and departure_time is not None:
         raise ApiError('arrival_time and departure_time cannot be both specified')
 
     if arrival_time is not None:
-        return DistrictsRequest(
+        return PostcodesDistrictsRequest(
             arrival_searches=[
-                zones.ArrivalSearch(
+                postcodes_zones.ArrivalSearch(
                     id=f'Search {ind}',
                     coords=cur_coordinates,
                     travel_time=travel_time,
@@ -212,16 +212,16 @@ def create_districts(
                     reachable_postcodes_threshold=reachable_postcodes_threshold,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for ind, cur_coordinates in enumerate(coordinates)
             ],
             departure_searches=[]
         )
     elif departure_time is not None:
-        return DistrictsRequest(
+        return PostcodesDistrictsRequest(
             departure_searches=[
-                zones.DepartureSearch(
+                postcodes_zones.DepartureSearch(
                     id=f'Search {ind}',
                     coords=cur_coordinates,
                     travel_time=travel_time,
@@ -229,7 +229,7 @@ def create_districts(
                     reachable_postcodes_threshold=reachable_postcodes_threshold,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for ind, cur_coordinates in enumerate(coordinates)
             ],
@@ -247,18 +247,18 @@ def create_sectors(
     arrival_time: Optional[datetime],
     reachable_postcodes_threshold,
     properties: Optional[List[ZonesProperty]],
-    full_range: Optional[FullRange]
-) -> SectorsRequest:
+    range: Optional[FullRange]
+) -> PostcodesSectorsRequest:
     if properties is None:
-        properties = ZonesProperty.TRAVEL_TIME_ALL
+        properties = [ZonesProperty.TRAVEL_TIME_ALL]
 
     if arrival_time is not None and departure_time is not None:
         raise ApiError('arrival_time and departure_time cannot be both specified')
 
     if arrival_time is not None:
-        return SectorsRequest(
+        return PostcodesSectorsRequest(
             arrival_searches=[
-                zones.ArrivalSearch(
+                postcodes_zones.ArrivalSearch(
                     id=f'Search {ind}',
                     coords=cur_coordinates,
                     travel_time=travel_time,
@@ -266,16 +266,16 @@ def create_sectors(
                     reachable_postcodes_threshold=reachable_postcodes_threshold,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for ind, cur_coordinates in enumerate(coordinates)
             ],
             departure_searches=[]
         )
     elif departure_time is not None:
-        return SectorsRequest(
+        return PostcodesSectorsRequest(
             departure_searches=[
-                zones.DepartureSearch(
+                postcodes_zones.DepartureSearch(
                     id=f'Search {ind}',
                     coords=cur_coordinates,
                     travel_time=travel_time,
@@ -283,7 +283,7 @@ def create_sectors(
                     reachable_postcodes_threshold=reachable_postcodes_threshold,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for ind, cur_coordinates in enumerate(coordinates)
             ],
@@ -467,7 +467,7 @@ def create_routes(
     departure_time: Optional[datetime],
     arrival_time: Optional[datetime],
     properties: Optional[List[Property]],
-    full_range: Optional[FullRange]
+    range: Optional[FullRange]
 ) -> RoutesRequest:
     if arrival_time is not None and departure_time is not None:
         raise ApiError('arrival_time and departure_time cannot be both specified')
@@ -485,7 +485,7 @@ def create_routes(
                     arrival_time=arrival_time,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for arrival_id, departure_ids in search_ids.items()
             ],
@@ -502,7 +502,7 @@ def create_routes(
                     departure_time=departure_time,
                     transportation=transportation,
                     properties=properties,
-                    full_range=full_range
+                    range=range
                 )
                 for departure_id, arrival_ids in search_ids.items()
             ],
