@@ -3,10 +3,11 @@ from typing import List, Optional, Dict, Union
 
 from traveltimepy.dto.common import Location, Coordinates, Rectangle, Property, FullRange, Range
 from traveltimepy.dto.transportation import PublicTransport, Driving, Ferry, Walking, Cycling, DrivingTrain
-from traveltimepy.dto.requests.zones import ZonesProperty
+from traveltimepy.dto.requests.postcodes_zones import ZonesProperty
 from traveltimepy.dto.requests.time_filter_proto import ProtoCountry, ProtoTransportation
 from traveltimepy.dto.requests.time_filter_fast import Transportation
 
+from traveltimepy.version import __version__
 from traveltimepy.accept_type import AcceptType
 from traveltimepy.itertools import join_opt
 from traveltimepy.dto.requests.supported_locations import SupportedLocationsRequest
@@ -18,7 +19,8 @@ from traveltimepy.dto.responses.supported_locations import SupportedLocationsRes
 from traveltimepy.dto.responses.time_filter import TimeFilterResponse, TimeFilterResult
 from traveltimepy.dto.responses.time_filter_fast import TimeFilterFastResponse, TimeFilterFastResult
 from traveltimepy.dto.responses.time_map import TimeMapResponse, TimeMapResult
-from traveltimepy.dto.responses.zones import DistrictsResponse, SectorsResponse, DistrictsResult, SectorsResult
+from traveltimepy.dto.responses.zones import PostcodesDistrictsResponse, PostcodesSectorsResponse,\
+    PostcodesDistrictsResult, PostcodesSectorsResult
 
 from traveltimepy.mapper import (
     create_time_filter,
@@ -37,7 +39,8 @@ from traveltimepy.http import (
     send_get,
     send_get_async,
     send_post,
-    send_post_async
+    send_post_async,
+    SdkParams
 )
 
 from geojson_pydantic import FeatureCollection
@@ -45,10 +48,10 @@ from geojson_pydantic import FeatureCollection
 
 class TravelTimeSdk:
 
-    def __init__(self, app_id: str, api_key: str, limit_per_host: int = 2) -> None:
+    def __init__(self, app_id: str, api_key: str, limit_per_host: int = 2, host: str = 'api.traveltimeapp.com') -> None:
         self.__app_id = app_id
         self.__api_key = api_key
-        self.__limit_per_host = limit_per_host
+        self.__sdk_params = SdkParams(host, limit_per_host)
 
     async def time_filter_async(
         self,
@@ -59,7 +62,7 @@ class TravelTimeSdk:
         departure_time: Optional[datetime] = None,
         arrival_time: Optional[datetime] = None,
         travel_time: int = 3600,
-        full_range: Optional[FullRange] = None
+        range: Optional[FullRange] = None
     ) -> List[TimeFilterResult]:
         resp = await send_post_async(
             TimeFilterResponse,
@@ -73,9 +76,9 @@ class TravelTimeSdk:
                 departure_time,
                 arrival_time,
                 travel_time,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         )
 
         return resp.results
@@ -89,7 +92,7 @@ class TravelTimeSdk:
         arrival_time: Optional[datetime] = None,
         properties: Optional[List[Property]] = None,
         travel_time: int = 3600,
-        full_range: Optional[FullRange] = None
+        range: Optional[FullRange] = None
     ) -> List[TimeFilterResult]:
         return send_post(
             TimeFilterResponse,
@@ -103,17 +106,17 @@ class TravelTimeSdk:
                 departure_time,
                 arrival_time,
                 travel_time,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         ).results
 
     async def map_info_async(self) -> List[Map]:
-        res = await send_get_async(MapInfoResponse, 'map-info', self.__headers(AcceptType.JSON))
+        res = await send_get_async(MapInfoResponse, 'map-info', self.__headers(AcceptType.JSON), self.__sdk_params)
         return res.maps
 
     def map_info(self) -> List[Map]:
-        return send_get(MapInfoResponse, 'map-info', self.__headers(AcceptType.JSON)).maps
+        return send_get(MapInfoResponse, 'map-info', self.__headers(AcceptType.JSON), self.__sdk_params).maps
 
     async def geocoding_async(
         self,
@@ -128,6 +131,7 @@ class TravelTimeSdk:
             FeatureCollection,
             'geocoding/search',
             self.__headers(AcceptType.JSON),
+            self.__sdk_params,
             self.__geocoding_params(
                 query,
                 limit,
@@ -151,6 +155,7 @@ class TravelTimeSdk:
             FeatureCollection,
             'geocoding/search',
             self.__headers(AcceptType.JSON),
+            self.__sdk_params,
             self.__geocoding_params(
                 query,
                 limit,
@@ -171,6 +176,7 @@ class TravelTimeSdk:
             FeatureCollection,
             'geocoding/reverse',
             self.__headers(AcceptType.JSON),
+            self.__sdk_params,
             self.__geocoding_reverse_params(lat, lng, within_countries)
         )
 
@@ -183,6 +189,7 @@ class TravelTimeSdk:
             FeatureCollection,
             'geocoding/reverse',
             self.__headers(AcceptType.JSON),
+            self.__sdk_params,
             self.__geocoding_reverse_params(lat, lng)
         )
 
@@ -192,7 +199,7 @@ class TravelTimeSdk:
             'supported-locations',
             self.__headers(AcceptType.JSON),
             SupportedLocationsRequest(locations=locations),
-            self.__limit_per_host
+            self.__sdk_params
         )
 
     def supported_locations(self, locations: List[Location]) -> SupportedLocationsResponse:
@@ -201,7 +208,7 @@ class TravelTimeSdk:
             'supported-locations',
             self.__headers(AcceptType.JSON),
             SupportedLocationsRequest(locations=locations),
-            self.__limit_per_host
+            self.__sdk_params
         )
 
     async def time_filter_fast_async(
@@ -225,7 +232,7 @@ class TravelTimeSdk:
                 properties,
                 one_to_many
             ),
-            self.__limit_per_host
+            self.__sdk_params
         )
         return resp.results
 
@@ -250,7 +257,7 @@ class TravelTimeSdk:
                 properties,
                 one_to_many
             ),
-            self.__limit_per_host
+            self.__sdk_params
         ).results
 
     async def postcodes_async(
@@ -261,7 +268,7 @@ class TravelTimeSdk:
         arrival_time: Optional[datetime] = None,
         travel_time: int = 1800,
         properties: Optional[List[Property]] = None,
-        full_range: Optional[FullRange] = None
+        range: Optional[FullRange] = None
     ) -> List[PostcodesResult]:
         resp = await send_post_async(
             PostcodesResponse,
@@ -274,9 +281,9 @@ class TravelTimeSdk:
                 transportation,
                 travel_time,
                 properties,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         )
         return resp.results
 
@@ -288,7 +295,7 @@ class TravelTimeSdk:
         arrival_time: Optional[datetime] = None,
         travel_time: int = 1800,
         properties: Optional[List[Property]] = None,
-        full_range: Optional[FullRange] = None
+        range: Optional[FullRange] = None
     ) -> List[PostcodesResult]:
         return send_post(
             PostcodesResponse,
@@ -301,12 +308,12 @@ class TravelTimeSdk:
                 transportation,
                 travel_time,
                 properties,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         ).results
 
-    async def districts_async(
+    async def postcodes_districts_async(
         self,
         coordinates: List[Coordinates],
         transportation: Union[PublicTransport, Driving, Ferry, Walking, Cycling, DrivingTrain],
@@ -315,10 +322,10 @@ class TravelTimeSdk:
         arrival_time: Optional[datetime] = None,
         reachable_postcodes_threshold=0.1,
         properties: Optional[List[ZonesProperty]] = None,
-        full_range: Optional[FullRange] = None
-    ) -> List[DistrictsResult]:
+        range: Optional[FullRange] = None
+    ) -> List[PostcodesDistrictsResult]:
         res = await send_post_async(
-            DistrictsResponse,
+            PostcodesDistrictsResponse,
             'time-filter/postcode-districts',
             self.__headers(AcceptType.JSON),
             create_districts(
@@ -329,13 +336,13 @@ class TravelTimeSdk:
                 arrival_time,
                 reachable_postcodes_threshold,
                 properties,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         )
         return res.results
 
-    def districts(
+    def postcode_districts(
         self,
         coordinates: List[Coordinates],
         transportation: Union[PublicTransport, Driving, Ferry, Walking, Cycling, DrivingTrain],
@@ -344,10 +351,10 @@ class TravelTimeSdk:
         arrival_time: Optional[datetime] = None,
         reachable_postcodes_threshold=0.1,
         properties: Optional[List[ZonesProperty]] = None,
-        full_range: Optional[FullRange] = None
-    ) -> List[DistrictsResult]:
+        range: Optional[FullRange] = None
+    ) -> List[PostcodesDistrictsResult]:
         return send_post(
-            DistrictsResponse,
+            PostcodesDistrictsResponse,
             'time-filter/postcode-districts',
             self.__headers(AcceptType.JSON),
             create_districts(
@@ -358,12 +365,12 @@ class TravelTimeSdk:
                 arrival_time,
                 reachable_postcodes_threshold,
                 properties,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         ).results
 
-    async def sectors_async(
+    async def postcodes_sectors_async(
         self,
         coordinates: List[Coordinates],
         transportation: Union[PublicTransport, Driving, Ferry, Walking, Cycling, DrivingTrain],
@@ -372,10 +379,10 @@ class TravelTimeSdk:
         arrival_time: Optional[datetime] = None,
         reachable_postcodes_threshold=0.1,
         properties: Optional[List[ZonesProperty]] = None,
-        full_range: Optional[FullRange] = None
-    ) -> List[SectorsResult]:
+        range: Optional[FullRange] = None
+    ) -> List[PostcodesSectorsResult]:
         resp = await send_post_async(
-            SectorsResponse,
+            PostcodesSectorsResponse,
             'time-filter/postcode-sectors',
             self.__headers(AcceptType.JSON),
             create_sectors(
@@ -386,13 +393,13 @@ class TravelTimeSdk:
                 arrival_time,
                 reachable_postcodes_threshold,
                 properties,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         )
         return resp.results
 
-    def sectors(
+    def postcode_sectors(
         self,
         coordinates: List[Coordinates],
         transportation: Union[PublicTransport, Driving, Ferry, Walking, Cycling, DrivingTrain],
@@ -401,10 +408,10 @@ class TravelTimeSdk:
         arrival_time: Optional[datetime] = None,
         reachable_postcodes_threshold=0.1,
         properties: Optional[List[ZonesProperty]] = None,
-        full_range: Optional[FullRange] = None
-    ) -> List[SectorsResult]:
+        range: Optional[FullRange] = None
+    ) -> List[PostcodesSectorsResult]:
         return send_post(
-            SectorsResponse,
+            PostcodesSectorsResponse,
             'time-filter/postcode-sectors',
             self.__headers(AcceptType.JSON),
             create_sectors(
@@ -415,9 +422,9 @@ class TravelTimeSdk:
                 arrival_time,
                 reachable_postcodes_threshold,
                 properties,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         ).results
 
     def routes(
@@ -428,7 +435,7 @@ class TravelTimeSdk:
         departure_time: Optional[datetime] = None,
         arrival_time: Optional[datetime] = None,
         properties: Optional[List[Property]] = None,
-        full_range: Optional[FullRange] = None
+        range: Optional[FullRange] = None
     ) -> List[RoutesResult]:
         return send_post(
             RoutesResponse,
@@ -441,9 +448,9 @@ class TravelTimeSdk:
                 departure_time,
                 arrival_time,
                 properties,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         ).results
 
     async def routes_async(
@@ -454,7 +461,7 @@ class TravelTimeSdk:
         departure_time: Optional[datetime] = None,
         arrival_time: Optional[datetime] = None,
         properties: Optional[List[Property]] = None,
-        full_range: Optional[FullRange] = None
+        range: Optional[FullRange] = None
     ) -> List[RoutesResult]:
         resp = await send_post_async(
             RoutesResponse,
@@ -467,9 +474,9 @@ class TravelTimeSdk:
                 departure_time,
                 arrival_time,
                 properties,
-                full_range
+                range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         )
         return resp.results
 
@@ -527,7 +534,7 @@ class TravelTimeSdk:
                 departure_time,
                 search_range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         ).results
 
     def intersection(
@@ -551,7 +558,7 @@ class TravelTimeSdk:
                 departure_time,
                 search_range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         ).results[0]
 
     async def intersection_async(
@@ -575,7 +582,7 @@ class TravelTimeSdk:
                 departure_time,
                 search_range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         )
         return resp.results[0]
 
@@ -600,7 +607,7 @@ class TravelTimeSdk:
                 departure_time,
                 search_range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         ).results[0]
 
     async def union_async(
@@ -624,7 +631,7 @@ class TravelTimeSdk:
                 departure_time,
                 search_range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         )
 
         return resp.results[0]
@@ -650,7 +657,7 @@ class TravelTimeSdk:
                 departure_time,
                 search_range
             ),
-            self.__limit_per_host
+            self.__sdk_params
         )
         return resp.results
 
@@ -688,14 +695,14 @@ class TravelTimeSdk:
     def __proto_headers() -> Dict[str, str]:
         return {
             'Content-Type': AcceptType.OCTET_STREAM.value,
-            'User-Agent': 'Travel Time Python Beta SDK'
+            'User-Agent': f'Travel Time Python SDK {__version__}'
         }
 
     def __headers(self, accept_type: AcceptType) -> Dict[str, str]:
         return {
             'X-Application-Id': self.__app_id,
             'X-Api-Key': self.__api_key,
-            'User-Agent': 'Travel Time Beta Python SDK',
+            'User-Agent': f'Travel Time Python SDK {__version__}',
             'Content-Type': 'application/json',
             'Accept': accept_type.value
         }
